--------------------------------- Dreamlayout.lua ---------------------------------
local L = AceLibrary("AceLocale-2.2"):new("Buffalo2")

local function abbrev__index (self, key)
	local value = ""
	for c in key:gmatch("(%w)%w*") do
		value = value .. c
	end

	rawset(self, key, value)
	return value
end

local abbrev = setmetatable({}, { __index = abbrev__index })

Buffalo2.Templates.DreamlayoutBuffs = {
	author = "Skyboat",
	growHorizontalFirst = true,
	growRight = false,
	growUpwards = false,
	rows = 4,
	cols = 8,
	xpad = 10,
	ypad = 15,
	scale = 1.1,

	GetName = function(container)
		return "Dreamlayout - Buffs and Weapon Enchants"
	end,

	GetDescription = function(container)
		return "Dreamlayout Style - Combines player buffs with temporary weapon enchants"
	end,

	ContainsBuff = function(container, buff)
		if (buff.unitID == "player" and buff.filter == "HELPFUL") then
			return true
		elseif (buff.unitID == "MH" or buff.unitID == "OH") then
			return true
		else
			return false
		end
	end,

	Comparator = function(container, buff1, buff2)
		if (buff2.unitID == "MH") then
			return false
		elseif (buff2.unitID == "OH" and buff1.unitID ~= "MH") then
			return false
		else
			return true
		end
	end,

	Buttons = {
		GetGhostColor = function(button)
			return 0.0, 1.0, 0.0, 0.7
		end,

		GetDurationString = function(button, buff)
			if (not buff.timeLeft) then
				return ""
			end
			if (buff.timeLeft > 3600) then
				return Buffalo2.abacus:FormatDurationCondensed(buff.timeLeft, true, true)
			else
				return Buffalo2.abacus:FormatDurationCondensed(buff.timeLeft, true, false)
			end
		end,

		GetLabelString = function(button, buff)
			if (buff.unitID == "OH" or buff.unitID == "MH") then
				return buff.unitID
			end
			local name = buff.buffName
			return abbrev[name]
		end,

		GetTimerAnchor = function(button)
			local anchor = {point = "TOP", relativePoint = "BOTTOM", xOffs = 0, yOffs = -2}
			return anchor
		end,

		GetLabelAnchor = function(button)
			local anchor = {point = "BOTTOM", relativePoint = "TOP", xOffs = 0, yOffs = 2}
			return anchor
		end,

		PostTimerUpdate = function(button)
		end,

		OnButtonCreation = function(button)
			local frame = CreateFrame("Frame", button.frame:GetName().."_Dreamlayout", button.frame)
			--frame:SetBackdrop({bgFile = "Interface\\Tooltips\\UI-Tooltip-Background", tile = true, tileSize = 1, edgeFile = "", edgeSize = 0, insets = {left = 0, right = 0, top = 0, bottom = 0},})
			frame:SetBackdrop({bgFile = "Interface\\ChatFrame\\ChatFrameBackground", tile = true, tileSize = 1, edgeFile = "", edgeSize = 0, insets = {left = 0, right = 0, top = 0, bottom = 0},})
			frame:SetBackdropColor(0, 0, 0, 0.6)
			frame:SetBackdropBorderColor(0.5, 0.5, 0, 0)
			frame:SetPoint("TOPLEFT", button.frame, "TOPLEFT", 0, 0)
			frame:SetPoint("BOTTOMRIGHT", button.frame, "BOTTOMRIGHT", 0, 0)
			frame:SetFrameLevel(1)

			local icon = getglobal(button.frame:GetName().."Icon")
			icon:SetTexCoord(0.09, 0.91, 0.09, 0.91)
			icon:ClearAllPoints()
			--icon:SetPoint("TOPLEFT", frame, "TOPLEFT", 3, -3)
			--icon:SetPoint("BOTTOMRIGHT", frame, "BOTTOMRIGHT", -3, 3)
			icon:SetPoint("TOPLEFT", frame, "TOPLEFT", 2, -2)
			icon:SetPoint("BOTTOMRIGHT", frame, "BOTTOMRIGHT", -2, 2)
		end,

		OnSetBuff = function(button, buff)
			local frame = getglobal(button.frame:GetName().."_Dreamlayout")
			if (buff.unitID == "MH") or (buff.unitID == "OH") then
				frame:SetBackdropColor(0.5, 0.2, 0.85, 1)
			else
				frame:SetBackdropColor(0, 0, 0, 0.6)
			end
		end,
	},
}

Buffalo2.Templates.DreamlayoutDebuffs = {
	author = "Skyboat",
	growHorizontalFirst = true,
	growRight = false,
	growUpwards = false,
	rows = 4,
	cols = 8,
	xpad = 10,
	ypad = 15,
	scale = 1.1,

	GetName = function(container)
		return "Dreamlayout - Debuffs"
	end,

	GetDescription = function(container)
		return "Dreamlayout Style - Displays player debuffs"
	end,

	ContainsBuff = function(container, buff)
		if (buff.unitID == "player" and buff.filter=="HARMFUL") then
			return true
		else
			return false
		end
	end,

	Buttons = {
		GetGhostColor = function(button)
			return 1.0, 0.0, 0.0, 0.7
		end,

		GetDurationString = function(button, buff)
			if (not buff.timeLeft) then
				return ""
			end
			if (buff.timeLeft > 3600) then
				return Buffalo2.abacus:FormatDurationCondensed(buff.timeLeft, true, true)
			else
				return Buffalo2.abacus:FormatDurationCondensed(buff.timeLeft, true, false)
			end
		end,

		GetLabelString = function(button, buff)
			if (buff.unitID == "OH" or buff.unitID == "MH") then
				return buff.unitID
			end
			local name = buff.buffName
			return abbrev[name]
		end,

		GetTimerAnchor = function(button)
			local anchor = {point = "TOP", relativePoint = "BOTTOM", xOffs = 0, yOffs = -2}
			return anchor
		end,

		GetLabelAnchor = function(button)
			local anchor = {point = "BOTTOM", relativePoint = "TOP", xOffs = 0, yOffs = 2}
			return anchor
		end,

		PostTimerUpdate = function(button)
		end,

		OnButtonCreation = function(button)
			local frame = CreateFrame("Frame", button.frame:GetName().."_Dreamlayout", button.frame)
			--frame:SetBackdrop({bgFile = "Interface\\Tooltips\\UI-Tooltip-Background", tile = true, tileSize = 1, edgeFile = "", edgeSize = 0, insets = {left = 0, right = 0, top = 0, bottom = 0},})
			frame:SetBackdrop({bgFile = "Interface\\ChatFrame\\ChatFrameBackground", tile = true, tileSize = 1, edgeFile = "", edgeSize = 0, insets = {left = 0, right = 0, top = 0, bottom = 0},})
			frame:SetBackdropColor(1, 0, 0, 1)
			frame:SetBackdropBorderColor(0.5, 0.5, 0, 0)
			frame:SetPoint("TOPLEFT", button.frame, "TOPLEFT", 0, 0)
			frame:SetPoint("BOTTOMRIGHT", button.frame, "BOTTOMRIGHT", 0, 0)
			frame:SetFrameLevel(1)

			local icon = getglobal(button.frame:GetName().."Icon")
			icon:SetTexCoord(0.09, 0.91, 0.09, 0.91)
			icon:ClearAllPoints()
			--icon:SetPoint("TOPLEFT", frame, "TOPLEFT", 3, -3)
			--icon:SetPoint("BOTTOMRIGHT", frame, "BOTTOMRIGHT", -3, 3)
			icon:SetPoint("TOPLEFT", frame, "TOPLEFT", 2, -2)
			icon:SetPoint("BOTTOMRIGHT", frame, "BOTTOMRIGHT", -2, 2)
		end,

		OnSetBuff = function(button, buff)
			local border = getglobal(button.frame:GetName().."_Border")
			if (border:IsShown()) then
				border:Hide()
			end

			local color
 			if (buff.debuffType) then
 				color = DebuffTypeColor[buff.debuffType]
 			else
 				color = DebuffTypeColor["none"]
 			end

 			local frame = getglobal(button.frame:GetName().."_Dreamlayout")
 			frame:SetBackdropColor(color.r, color.g, color.b, 1)
		end,
	},
}
